pub struct WebView<T = ()> {
Show 15 fields pub is_handle: bool, pub objc: ObjcProperty, pub layer: Layer, pub objc_delegate: Option<ShareId<Object>>, pub delegate: Option<Box<T>>, pub top: LayoutAnchorY, pub leading: LayoutAnchorX, pub left: LayoutAnchorX, pub trailing: LayoutAnchorX, pub right: LayoutAnchorX, pub bottom: LayoutAnchorY, pub width: LayoutAnchorDimension, pub height: LayoutAnchorDimension, pub center_x: LayoutAnchorX, pub center_y: LayoutAnchorY,
}
Available on crate feature webview only.

Fields

is_handle: bool

An internal flag for whether an instance of a View is a handle. Typically, there’s only one instance that should have this set to false - if that one drops, we need to know to do some extra cleanup.

objc: ObjcProperty

A pointer to the Objective-C runtime view controller.

layer: Layer

A reference to the underlying CALayer.

objc_delegate: Option<ShareId<Object>>

We need to store the underlying delegate separately from the WKWebView - this is a where we do so.

delegate: Option<Box<T>>

A pointer to the delegate for this view.

top: LayoutAnchorY

A pointer to the Objective-C runtime top layout constraint.

leading: LayoutAnchorX

A pointer to the Objective-C runtime leading layout constraint.

left: LayoutAnchorX

A pointer to the Objective-C runtime left layout constraint.

trailing: LayoutAnchorX

A pointer to the Objective-C runtime trailing layout constraint.

right: LayoutAnchorX

A pointer to the Objective-C runtime right layout constraint.

bottom: LayoutAnchorY

A pointer to the Objective-C runtime bottom layout constraint.

width: LayoutAnchorDimension

A pointer to the Objective-C runtime width layout constraint.

height: LayoutAnchorDimension

A pointer to the Objective-C runtime height layout constraint.

center_x: LayoutAnchorX

A pointer to the Objective-C runtime center X layout constraint.

center_y: LayoutAnchorY

A pointer to the Objective-C runtime center Y layout constraint.

Implementations

Returns a default WebView, suitable for customizing and displaying.

Initializes a new WebView with a given WebViewDelegate. This enables you to respond to events and customize the view as a module, similar to class-based systems.

Given a URL, instructs the WebView to load it.

Given a HTML string, instructs the WebView to load it. Useful for small html files, but often better to use custom protocol.

Go back in history, if possible.

Go forward in history, if possible.