pub struct WebView<T = ()> {Show 15 fields
pub is_handle: bool,
pub objc: ObjcProperty,
pub layer: Layer,
pub objc_delegate: Option<ShareId<Object>>,
pub delegate: Option<Box<T>>,
pub top: LayoutAnchorY,
pub leading: LayoutAnchorX,
pub left: LayoutAnchorX,
pub trailing: LayoutAnchorX,
pub right: LayoutAnchorX,
pub bottom: LayoutAnchorY,
pub width: LayoutAnchorDimension,
pub height: LayoutAnchorDimension,
pub center_x: LayoutAnchorX,
pub center_y: LayoutAnchorY,
}webview only.Fields
is_handle: boolAn internal flag for whether an instance of a Viewfalse - if that one drops, we need to know to
do some extra cleanup.
objc: ObjcPropertyA pointer to the Objective-C runtime view controller.
layer: LayerA reference to the underlying CALayer.
objc_delegate: Option<ShareId<Object>>We need to store the underlying delegate separately from the WKWebView - this is a where
we do so.
delegate: Option<Box<T>>A pointer to the delegate for this view.
top: LayoutAnchorYA pointer to the Objective-C runtime top layout constraint.
leading: LayoutAnchorXA pointer to the Objective-C runtime leading layout constraint.
left: LayoutAnchorXA pointer to the Objective-C runtime left layout constraint.
trailing: LayoutAnchorXA pointer to the Objective-C runtime trailing layout constraint.
right: LayoutAnchorXA pointer to the Objective-C runtime right layout constraint.
bottom: LayoutAnchorYA pointer to the Objective-C runtime bottom layout constraint.
width: LayoutAnchorDimensionA pointer to the Objective-C runtime width layout constraint.
height: LayoutAnchorDimensionA pointer to the Objective-C runtime height layout constraint.
center_x: LayoutAnchorXA pointer to the Objective-C runtime center X layout constraint.
center_y: LayoutAnchorYA pointer to the Objective-C runtime center Y layout constraint.
Implementations
sourceimpl WebView
impl WebView
sourcepub fn new(config: WebViewConfig) -> Self
pub fn new(config: WebViewConfig) -> Self
Returns a default WebView, suitable for customizing and displaying.
sourceimpl<T> WebView<T> where
T: WebViewDelegate + 'static,
impl<T> WebView<T> where
T: WebViewDelegate + 'static,
sourcepub fn with(config: WebViewConfig, delegate: T) -> WebView<T>
pub fn with(config: WebViewConfig, delegate: T) -> WebView<T>
Initializes a new WebView with a given WebViewDelegate. This enables you to respond to events
and customize the view as a module, similar to class-based systems.